@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -234,6 +234,33 @@ class EndpointServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates an Endpoint.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            async def sample_create_endpoint():
+                # Create a client
+                client = aiplatform_v1.EndpointServiceAsyncClient()
+
+                # Initialize request argument(s)
+                endpoint = aiplatform_v1.Endpoint()
+                endpoint.display_name = "display_name_value"
+
+                request = aiplatform_v1.CreateEndpointRequest(
+                    parent="parent_value",
+                    endpoint=endpoint,
+                )
+
+                # Make the request
+                operation = client.create_endpoint(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.CreateEndpointRequest, dict]):
                 The request object. Request message for
@@ -316,7 +343,12 @@ class EndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -340,6 +372,25 @@ class EndpointServiceAsyncClient:
     ) -> endpoint.Endpoint:
         r"""Gets an Endpoint.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            async def sample_get_endpoint():
+                # Create a client
+                client = aiplatform_v1.EndpointServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.GetEndpointRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = await client.get_endpoint(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.GetEndpointRequest, dict]):
                 The request object. Request message for
@@ -396,7 +447,12 @@ class EndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -412,6 +468,26 @@ class EndpointServiceAsyncClient:
     ) -> pagers.ListEndpointsAsyncPager:
         r"""Lists Endpoints in a Location.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            async def sample_list_endpoints():
+                # Create a client
+                client = aiplatform_v1.EndpointServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.ListEndpointsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_endpoints(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.ListEndpointsRequest, dict]):
                 The request object. Request message for
@@ -471,12 +547,20 @@ class EndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListEndpointsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -494,6 +578,28 @@ class EndpointServiceAsyncClient:
     ) -> gca_endpoint.Endpoint:
         r"""Updates an Endpoint.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            async def sample_update_endpoint():
+                # Create a client
+                client = aiplatform_v1.EndpointServiceAsyncClient()
+
+                # Initialize request argument(s)
+                endpoint = aiplatform_v1.Endpoint()
+                endpoint.display_name = "display_name_value"
+
+                request = aiplatform_v1.UpdateEndpointRequest(
+                    endpoint=endpoint,
+                )
+
+                # Make the request
+                response = await client.update_endpoint(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.UpdateEndpointRequest, dict]):
                 The request object. Request message for
@@ -561,7 +667,12 @@ class EndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -577,6 +688,29 @@ class EndpointServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes an Endpoint.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            async def sample_delete_endpoint():
+                # Create a client
+                client = aiplatform_v1.EndpointServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.DeleteEndpointRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_endpoint(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.DeleteEndpointRequest, dict]):
                 The request object. Request message for
@@ -646,7 +780,12 @@ class EndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -665,9 +804,7 @@ class EndpointServiceAsyncClient:
         *,
         endpoint: str = None,
         deployed_model: gca_endpoint.DeployedModel = None,
-        traffic_split: Sequence[
-            endpoint_service.DeployModelRequest.TrafficSplitEntry
-        ] = None,
+        traffic_split: Mapping[str, int] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -675,6 +812,34 @@ class EndpointServiceAsyncClient:
         r"""Deploys a Model into this Endpoint, creating a
         DeployedModel within it.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            async def sample_deploy_model():
+                # Create a client
+                client = aiplatform_v1.EndpointServiceAsyncClient()
+
+                # Initialize request argument(s)
+                deployed_model = aiplatform_v1.DeployedModel()
+                deployed_model.dedicated_resources.min_replica_count = 1803
+                deployed_model.model = "model_value"
+
+                request = aiplatform_v1.DeployModelRequest(
+                    endpoint="endpoint_value",
+                    deployed_model=deployed_model,
+                )
+
+                # Make the request
+                operation = client.deploy_model(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.DeployModelRequest, dict]):
                 The request object. Request message for
@@ -698,7 +863,7 @@ class EndpointServiceAsyncClient:
                 This corresponds to the ``deployed_model`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            traffic_split (:class:`Sequence[google.cloud.aiplatform_v1.types.DeployModelRequest.TrafficSplitEntry]`):
+            traffic_split (:class:`Mapping[str, int]`):
                 A map from a DeployedModel's ID to the percentage of
                 this Endpoint's traffic that should be forwarded to that
                 DeployedModel.
@@ -771,7 +936,12 @@ class EndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -790,9 +960,7 @@ class EndpointServiceAsyncClient:
         *,
         endpoint: str = None,
         deployed_model_id: str = None,
-        traffic_split: Sequence[
-            endpoint_service.UndeployModelRequest.TrafficSplitEntry
-        ] = None,
+        traffic_split: Mapping[str, int] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -801,6 +969,30 @@ class EndpointServiceAsyncClient:
         DeployedModel from it, and freeing all resources it's
         using.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            async def sample_undeploy_model():
+                # Create a client
+                client = aiplatform_v1.EndpointServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.UndeployModelRequest(
+                    endpoint="endpoint_value",
+                    deployed_model_id="deployed_model_id_value",
+                )
+
+                # Make the request
+                operation = client.undeploy_model(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.UndeployModelRequest, dict]):
                 The request object. Request message for
@@ -820,7 +1012,7 @@ class EndpointServiceAsyncClient:
                 This corresponds to the ``deployed_model_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            traffic_split (:class:`Sequence[google.cloud.aiplatform_v1.types.UndeployModelRequest.TrafficSplitEntry]`):
+            traffic_split (:class:`Mapping[str, int]`):
                 If this field is provided, then the Endpoint's
                 [traffic_split][google.cloud.aiplatform.v1.Endpoint.traffic_split]
                 will be overwritten with it. If last DeployedModel is
@@ -887,7 +1079,12 @@ class EndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
