@@ -234,8 +234,28 @@ class UpdateModelRequest(proto.Message):
 
     Attributes:
         model (google.cloud.aiplatform_v1.types.Model):
-            Required. The Model which replaces the
-            resource on the server.
+            Required. The Model which replaces the resource on the
+            server. When Model Versioning is enabled, the model.name
+            will be used to determine whether to update the model or
+            model version.
+
+            1. model.name with the @ value, e.g. models/123@1, refers to
+               a version specific update.
+            2. model.name without the @ value, e.g. models/123, refers
+               to a model update.
+            3. model.name with @-, e.g. models/123@-, refers to a model
+               update.
+            4. Supported model fields: display_name, description;
+               supported version-specific fields: version_description.
+               Labels are supported in both scenarios. Both the model
+               labels and the version labels are merged when a model is
+               returned. When updating labels, if the request is for
+               model-specific update, model label gets updated.
+               Otherwise, version labels get updated.
+            5. A model name or model version name fields update mismatch
+               will cause a precondition error.
+            6. One request cannot update both the model and the version
+               fields. You must update them separately.
         update_mask (google.protobuf.field_mask_pb2.FieldMask):
             Required. The update mask applies to the resource. For the
             ``FieldMask`` definition, see
