@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -68,7 +68,10 @@ class DatasetServiceClientMeta(type):
     _transport_registry["grpc"] = DatasetServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = DatasetServiceGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[DatasetServiceTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[DatasetServiceTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -176,7 +179,11 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
 
     @staticmethod
     def annotation_path(
-        project: str, location: str, dataset: str, data_item: str, annotation: str,
+        project: str,
+        location: str,
+        dataset: str,
+        data_item: str,
+        annotation: str,
     ) -> str:
         """Returns a fully-qualified annotation string."""
         return "projects/{project}/locations/{location}/datasets/{dataset}/dataItems/{data_item}/annotations/{annotation}".format(
@@ -198,7 +205,10 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
 
     @staticmethod
     def annotation_spec_path(
-        project: str, location: str, dataset: str, annotation_spec: str,
+        project: str,
+        location: str,
+        dataset: str,
+        annotation_spec: str,
     ) -> str:
         """Returns a fully-qualified annotation_spec string."""
         return "projects/{project}/locations/{location}/datasets/{dataset}/annotationSpecs/{annotation_spec}".format(
@@ -219,11 +229,17 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
 
     @staticmethod
     def data_item_path(
-        project: str, location: str, dataset: str, data_item: str,
+        project: str,
+        location: str,
+        dataset: str,
+        data_item: str,
     ) -> str:
         """Returns a fully-qualified data_item string."""
         return "projects/{project}/locations/{location}/datasets/{dataset}/dataItems/{data_item}".format(
-            project=project, location=location, dataset=dataset, data_item=data_item,
+            project=project,
+            location=location,
+            dataset=dataset,
+            data_item=data_item,
         )
 
     @staticmethod
@@ -236,10 +252,16 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def dataset_path(project: str, location: str, dataset: str,) -> str:
+    def dataset_path(
+        project: str,
+        location: str,
+        dataset: str,
+    ) -> str:
         """Returns a fully-qualified dataset string."""
         return "projects/{project}/locations/{location}/datasets/{dataset}".format(
-            project=project, location=location, dataset=dataset,
+            project=project,
+            location=location,
+            dataset=dataset,
         )
 
     @staticmethod
@@ -252,7 +274,9 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -265,9 +289,13 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -276,9 +304,13 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -287,9 +319,13 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -298,10 +334,14 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -487,8 +527,7 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> gac_operation.Operation:
         r"""Creates a Dataset.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
@@ -583,7 +622,12 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
@@ -607,8 +651,7 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> dataset.Dataset:
         r"""Gets a Dataset.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
@@ -682,7 +725,12 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -699,8 +747,7 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> gca_dataset.Dataset:
         r"""Updates a Dataset.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
@@ -796,7 +843,12 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -812,8 +864,7 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> pagers.ListDatasetsPager:
         r"""Lists Datasets in a Location.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
@@ -891,12 +942,20 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListDatasetsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -913,8 +972,7 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> gac_operation.Operation:
         r"""Deletes a Dataset.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
@@ -1006,7 +1064,12 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
@@ -1031,8 +1094,7 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> gac_operation.Operation:
         r"""Imports data into a Dataset.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
@@ -1129,7 +1191,12 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
@@ -1154,8 +1221,7 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> gac_operation.Operation:
         r"""Exports data from a Dataset.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
@@ -1250,7 +1316,12 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
@@ -1274,8 +1345,7 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> pagers.ListDataItemsPager:
         r"""Lists DataItems in a Dataset.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
@@ -1354,12 +1424,20 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListDataItemsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1376,8 +1454,7 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> annotation_spec.AnnotationSpec:
         r"""Gets an AnnotationSpec.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
@@ -1452,7 +1529,12 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1468,8 +1550,7 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> pagers.ListAnnotationsPager:
         r"""Lists Annotations belongs to a dataitem
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
@@ -1548,12 +1629,20 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListAnnotationsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
